==> rel_0.0.2.tar.bz2: driver/pt1_tuner_data.h <==
#ifndef		__PT1_TUNER_DATA_H__
#define		__PT1_TUNER_DATA_H__
/***************************************************************************/
/*                                                                         */
/***************************************************************************/
#define		MAX_ISDB_S_INIT		19			// ISDB-S ǡ
#define		MAX_ISDB_T_INIT		16			// ISDB-S ǡ
#define		MAX_BS_CHANNEL		12			// ȿơ֥
#define		MAX_ISDB_T_CHANNEL	113			// ȿơ֥(ϥǥ)
#define		MAX_BS_CHANNEL_PLL_COMMAND	3	// PLLå뤿Υޥɿ
/***************************************************************************/
/*                                                                         */
/***************************************************************************/

/***************************************************************************/
/*                                                                         */
/***************************************************************************/
typedef	struct	_WBLOCK_BS_PLL{
	WBLOCK	*wblock[MAX_BS_CHANNEL_PLL_COMMAND] ;
}WBLOCK_BS_PLL;

/***************************************************************************/
/*                                                                         */
/***************************************************************************/
extern	WBLOCK	com_initdata;		//()
extern	WBLOCK	isdb_s_init1;		//ISDB-SƬ
extern	WBLOCK	isdb_s_init21;		//ISDB-Sǽ
extern	WBLOCK	isdb_t_init17;		//ISDB-Tǽ
extern	WBLOCK	bs_pll_lock;		//ISDB-S PLLåǧ
extern	WBLOCK	*isdb_s_initial[MAX_ISDB_S_INIT];
extern	WBLOCK	*isdb_t_initial[MAX_ISDB_T_INIT];
/***************************************************************************/
/* BSѥǡ                                                          */
/***************************************************************************/
extern	WBLOCK_BS_PLL	bs_pll[MAX_BS_CHANNEL] ;	// ȿơ֥
extern	WBLOCK	*bs_get_ts_id[(MAX_BS_TS_ID / 2)] ;	// TS-IDơ֥
extern	WBLOCK	bs_tmcc_get_1;						// TMCCơ֥
extern	WBLOCK	bs_tmcc_get_2;						// TMCCơ֥
extern	WBLOCK	bs_get_ts_lock;
extern	WBLOCK	bs_set_ts_lock;
extern	WBLOCK	bs_get_slot;
extern	WBLOCK	bs_get_clock;
extern	WBLOCK	bs_get_carrir;
extern	WBLOCK	bs_get_cn;
extern	WBLOCK	bs_get_agc;
extern	WBLOCK	bs_get_maxagc;
/***************************************************************************/
/* ϥǥѥǡ                                                      */
/***************************************************************************/
extern	WBLOCK	*isdb_t_pll[MAX_ISDB_T_CHANNEL];			// ϥǥѼȿơ֥
extern	WBLOCK	isdb_t_pll_lock;
extern	WBLOCK_BS_PLL	isdb_t_info[MAX_ISDB_T_INFO_LEN];
extern	WBLOCK	isdb_t_check_tune;
extern	WBLOCK	isdb_t_tune_read;
extern	WBLOCK	isdb_t_tmcc_read_1;
extern	WBLOCK	isdb_t_tmcc_read_1;
extern	WBLOCK	isdb_t_cn_1;
extern	WBLOCK	isdb_t_cn_2;
extern	WBLOCK	isdb_t_agc_1;
extern	WBLOCK	isdb_t_agc_2;

extern	WBLOCK	isdb_t_get_clock;
extern	WBLOCK	isdb_t_get_carrir;

/***************************************************************************/
/* ѥǡ                                                      */
/***************************************************************************/
extern	WBLOCK	isdb_s_wake;
extern	WBLOCK	isdb_t_wake;

extern	WBLOCK	isdb_s_sleep;
extern	WBLOCK	isdb_t_sleep;

extern	ISDB_S_CH_TABLE	isdb_t_table[11];

#endif

==> rel_0.0.3.tar.bz2: driver/pt1_tuner_data.h <==
#ifndef		__PT1_TUNER_DATA_H__
#define		__PT1_TUNER_DATA_H__
/***************************************************************************/
/*                                                                         */
/***************************************************************************/
#define		MAX_ISDB_S_INIT		19			// ISDB-S ǡ
#define		MAX_ISDB_T_INIT		16			// ISDB-S ǡ
#define		MAX_BS_CHANNEL		36			// ȿơ֥
#define		MAX_ISDB_T_CHANNEL	113			// ȿơ֥(ϥǥ)
#define		MAX_BS_CHANNEL_PLL_COMMAND	3	// PLLå뤿Υޥɿ
/***************************************************************************/
/*                                                                         */
/***************************************************************************/

/***************************************************************************/
/*                                                                         */
/***************************************************************************/
typedef	struct	_WBLOCK_BS_PLL{
	WBLOCK	*wblock[MAX_BS_CHANNEL_PLL_COMMAND] ;
}WBLOCK_BS_PLL;

/***************************************************************************/
/*                                                                         */
/***************************************************************************/
extern	WBLOCK	com_initdata;		//()
extern	WBLOCK	isdb_s_init1;		//ISDB-SƬ
extern	WBLOCK	isdb_s_init21;		//ISDB-Sǽ
extern	WBLOCK	isdb_t_init17;		//ISDB-Tǽ
extern	WBLOCK	bs_pll_lock;		//ISDB-S PLLåǧ
extern	WBLOCK	*isdb_s_initial[MAX_ISDB_S_INIT];
extern	WBLOCK	*isdb_t_initial[MAX_ISDB_T_INIT];
/***************************************************************************/
/* BSѥǡ                                                          */
/***************************************************************************/
extern	WBLOCK_BS_PLL	bs_pll[MAX_BS_CHANNEL] ;	// ȿơ֥
extern	WBLOCK	*bs_get_ts_id[(MAX_BS_TS_ID / 2)] ;	// TS-IDơ֥
extern	WBLOCK	bs_tmcc_get_1;						// TMCCơ֥
extern	WBLOCK	bs_tmcc_get_2;						// TMCCơ֥
extern	WBLOCK	bs_get_ts_lock;
extern	WBLOCK	bs_set_ts_lock;
extern	WBLOCK	bs_get_slot;
extern	WBLOCK	bs_get_clock;
extern	WBLOCK	bs_get_carrir;
extern	WBLOCK	bs_get_cn;
extern	WBLOCK	bs_get_agc;
extern	WBLOCK	bs_get_maxagc;
/***************************************************************************/
/* ϥǥѥǡ                                                      */
/***************************************************************************/
extern	WBLOCK	isdb_t_pll_base;			// ϥǥѼȿơ֥base
extern	WBLOCK	isdb_t_pll_lock;
extern	WBLOCK_BS_PLL	isdb_t_info[MAX_ISDB_T_INFO_LEN];
extern	WBLOCK	isdb_t_check_tune;
extern	WBLOCK	isdb_t_tune_read;
extern	WBLOCK	isdb_t_tmcc_read_1;
extern	WBLOCK	isdb_t_tmcc_read_1;
extern	WBLOCK	isdb_t_cn_1;
extern	WBLOCK	isdb_t_cn_2;
extern	WBLOCK	isdb_t_agc_1;
extern	WBLOCK	isdb_t_agc_2;

extern	WBLOCK	isdb_t_get_clock;
extern	WBLOCK	isdb_t_get_carrir;

/***************************************************************************/
/* ѥǡ                                                      */
/***************************************************************************/
extern	WBLOCK	isdb_s_wake;
extern	WBLOCK	isdb_t_wake;

extern	WBLOCK	isdb_s_sleep;
extern	WBLOCK	isdb_t_sleep;

extern	ISDB_S_CH_TABLE	isdb_t_table[11];

#endif
